@@ -1,7 +1,7 @@
 #!/bin/sh
 #
 # fstrcmp - fuzzy string compare library
-# Copyright (C) 2009 Peter Miller
+# Copyright (C) 2009, 2011 Peter Miller
 # Written by Peter Miller <pmiller@opensource.org.au>
 #
 # This program is free software; you can redistribute it and/or modify
@@ -20,16 +20,16 @@
 
 sortflag=
 if test "$1" = "-r"; then
-        sortflag=r
+        sortflag=-r
         shift
 fi
 echo $* |
 tr ' ' '\12' |
-sort -t. +1n$sortflag -2 +2n$sortflag -3 +3n$sortflag -5 |
+sort $sortflag -V |
 while read f
 do
         echo ".br"
         echo ".so $f"
 done
 exit 0
-# vim:ts=8:sw=4:et
+# vim: set ts=8 sw=4 et :
